pytilities.aop.functions — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.aop »

# pytilities.aop.functions

`pytilities.aop.functions.` `_wrapped_call`(obj, name, f, args, kwargs)

  Used for handling call to returned callables of get

  This allows for support of bound methods, ...

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.aop »